@@ -8,7 +8,7 @@ import subprocess
 import skrt.image
 from skrt.structures import ROI, StructureSet
 from skrt.core import get_logger, Data, to_list, Defaults
-from skrt.dose import ImageOverlay
+from skrt.dose import ImageOverlay, Dose
 
 _ELASTIX_DIR = None
 _ELASTIX = "elastix"
@@ -19,7 +19,7 @@ class Registration(Data):
 
     def __init__(
         self, path, fixed=None, moving=None, pfiles=None, auto=False,
-        overwrite=False, capture_output=False, log_level=None):
+        overwrite=False, tfiles={}, capture_output=False, log_level=None):
         """Load data for an image registration and run the registration if
         auto_seg=True.
 
@@ -64,6 +64,12 @@ class Registration(Data):
             If True and <path> already contains files, these will be deleted,
             meaning that no prior registration results will be loaded.
 
+        tfiles: dict, default={}
+            Dictionary of pre-defined transforms, where a keys is a
+            registration step and the associated value is the path to
+            a pre-defined registration transform.  This parameter is
+            considered only if pfiles is null.
+
         capture_output : bool, default=False
             If True, capture to stdout messages from performing
             registration and transformation.  This suppresses
@@ -116,6 +122,11 @@ class Registration(Data):
         else:
             self.load_pfiles()
 
+        if not self.pfiles:
+            self.tfiles = tfiles
+            for step in sorted(tfiles):
+                self.steps.append(step)
+
         # Perform registration
         if auto:
             self.register()
@@ -612,6 +623,13 @@ class Registration(Data):
             so you will need to use double quotes.
         """
 
+        # If image is a Dose object, set pixel type to float
+        if params is None:
+            params = {}
+        is_dose = isinstance(im, Dose)
+        if is_dose:
+            params["ResultImagePixelType"] = "float"
+
         # Save image temporarily as nifti if needed
         im = skrt.image.Image(im)
         self.make_tmp_dir()
@@ -632,20 +650,23 @@ class Registration(Data):
             return
 
         # Otherwise, return Image object
-        final_im = skrt.image.Image(result_path)
-        self.rm_tmp_dir()
-
-        # Transform structure sets
-        if rois == "all":
-            rois_to_transform = im.structure_sets
-        elif isinstance(rois, int):
-            rois_to_transform = [im.structure_sets[rois]]
+        if is_dose:
+            final_im = Dose(result_path)
         else:
-            rois_to_transform = []
-        for ss in rois_to_transform:
-            ss2 = self.transform_structure_set(ss, step=step)
-            final_im.add_structure_set(ss2)
+            final_im = skrt.image.Image(result_path)
 
+            # Transform structure sets
+            if rois == "all":
+                rois_to_transform = im.structure_sets
+            elif isinstance(rois, int):
+                rois_to_transform = [im.structure_sets[rois]]
+            else:
+                rois_to_transform = []
+            for ss in rois_to_transform:
+                ss2 = self.transform_structure_set(ss, step=step)
+                final_im.add_structure_set(ss2)
+
+        self.rm_tmp_dir()
         return final_im
 
     def transform_data(self, path, step=-1, params=None):
@@ -772,9 +793,12 @@ class Registration(Data):
         roi = ROI(result_path, name=roi.name, color=roi.color)
         self.rm_tmp_dir()
         if transform_points:
-            roi.set_image(self.moving_image)
+            if hasattr(self, 'moving_image'):
+                roi.set_image(self.moving_image)
         else:
-            roi.set_image(self.get_transformed_image(step))
+            transformed_image = self.get_transformed_image(step)
+            if transformed_image is not None:
+                roi.set_image(transformed_image)
         return roi
 
     def transform_structure_set(
@@ -831,9 +855,12 @@ class Registration(Data):
         # Otherwise, return structure set
         final.name = "Transformed"
         if transform_points:
-            final.set_image(self.moving_image)
+            if hasattr(self, 'moving_image'):
+                final.set_image(self.moving_image)
         else:
-            final.set_image(self.get_transformed_image(step))
+            transformed_image = self.get_transformed_image(step)
+            if transformed_image is not None:
+                final.set_image(transformed_image)
         return final
 
     def transform_moving_image(self, step=-1):
@@ -863,7 +890,10 @@ class Registration(Data):
             self.transform_moving_image(step)
 
         # Return clone of the transformed image object
-        return self.transformed_images[step].clone()
+        if step in self.transformed_images:
+            return self.transformed_images[step].clone()
+        else:
+            return None
 
     def ensure_registered(self, step):
         """If a step has not already been registered, perform registration
